@@ -6,11 +6,11 @@ pub use mem::*;
 mod tests {
     
     #[test]
-    fn test_const() {
+    fn test_immutable() {
         use crate::*;
 
         fn test_new() {
-            let const_mem = Const::new(12);
+            let const_mem = Immutable::new(12);
 
             let _get_ok = match const_mem.get(11) {
                 Ok(ok) => assert_eq!(ok, 0x0),
@@ -27,7 +27,7 @@ mod tests {
         }
 
         fn test_from() {
-            let const_mem = Const::from(vec![1, 2, 3, 4, 5]);
+            let const_mem = Immutable::from(vec![1, 2, 3, 4, 5]);
 
             let _get_ok = match const_mem.get(2) {
                 Ok(ok) => assert_eq!(ok, 3),
