@@ -2,19 +2,19 @@ pub use super::*;
 
 pub type Byte = u128;
 
-pub struct Const {
+pub struct Immutable {
     memory: Vec<Byte>
 }
 
-impl Const {
-    pub fn new(size: usize) -> Const {
-        Const {
+impl Immutable {
+    pub fn new(size: usize) -> Immutable {
+        Immutable {
             memory: vec![0x0; size]
         }
     }
 
-    pub fn from(memory: Vec<Byte>) -> Const {
-        Const {
+    pub fn from(memory: Vec<Byte>) -> Immutable {
+        Immutable {
             memory
         }
     }
